Enabled all bandwidths, added Modtronix inAir9 module

Dependents:   SX1276PingPong_modtronix

Fork of SX1276Lib by Gregory Cristian

Revision:
22:20db480143c9
Parent:
20:7cf7c08f0088
Child:
23:2da0dcafe430
--- a/sx1276/sx1276.h	Thu Apr 02 12:27:47 2015 +1100
+++ b/sx1276/sx1276.h	Wed May 13 10:24:04 2015 +1000
@@ -69,7 +69,7 @@
     InterruptIn dio0;
     InterruptIn dio1;
     InterruptIn dio2; 
     //For SHD3I with inAir9 in imod3, on FRDM-KL25Z board. It uses A4 on FRDM-KL25Z board, which does not have interrupt
     #if( defined ( TARGET_KL25Z ) && defined(SHIELD_SHD3I_INAIR9) )
     DigitalIn dio3;
     #else
@@ -80,7 +80,7 @@
     
     bool isRadioActive;
     
-    uint8_t boardConnected; //1 = SX1276MB1LAS; 0 = SX1276MB1MAS
+    uint8_t boardConnected; //0 = BOARD_INAIR4; 1 = BOARD_INAIR9, 2 = BOARD_INAIR9B
     
     uint8_t *rxBuffer;
     
@@ -127,6 +127,22 @@
     //-------------------------------------------------------------------------
     //                        Redefined Radio functions
     //-------------------------------------------------------------------------
+
+    /*!
+     * Return board type
+     *
+     * @param BoardType enum
+     */
+    virtual uint8_t GetBoardType( void );
+
+
+    /*!
+     * Sets the board type, is a BOARD_XXX define
+     *
+     * @param boardType The board type, is a BOARD_XXX define
+     */
+    virtual void SetBoardType( uint8_t boardType);
+
     /*!
      * Return current radio status
      *
@@ -69,7 +69,7 @@
     InterruptIn dio1;
     InterruptIn dio2; 
-    //For SHD3I with inAir9 in imod3, on FRDM-KL25Z board. It uses A4 on FRDM-KL25Z board, which does not have interrupt
+    //For SHD3I with BOARD_INAIR4 in imod3, on FRDM-KL25Z board. It uses A4 on FRDM-KL25Z board, which does not have interrupt
     #if( defined ( TARGET_KL25Z ) && defined(SHIELD_SHD3I_INAIR9) )
     DigitalIn dio3;